Learn R Programming

MVar (version 2.0.4)

Biplot: Biplot graph.

Description

Plots the Biplot graph.

Usage

Biplot(Data, alpha = 0.5, Title = NA, xlabel = NA, ylabel = NA,
       Color = TRUE, Obs = TRUE, LinLab = NA)

Arguments

Data

Data for plotting.

alpha

Representativeness of the individuals (alpha), representativeness of the variables (1 - alpha), being 0.5 the default.

Title

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

Color

Colored graphics (default = TRUE).

Obs

Adds the observations to the graph (default = TRUE).

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

Value

Biplot

Biplot graph.

Md

Matrix eigenvalues.

Mu

Matrix U (eigenvectors).

Mv

Matrix V (eigenvectors).

Coor_I

Coordinates of the individuals.

Coor_V

Coordinates of the variables.

PVar

Proportion of the principal components.

References

RENCHER, A. C. Methods of Multivariate Analysis. 2th. ed. New York: J.Wiley, 2002. 708 p.

Examples

Run this code
# NOT RUN {
data(DataQuan) # set of quantitative data

Data <- DataQuan[,2:ncol(DataQuan)]
rownames(Data) <- DataQuan[,1]

Biplot(Data)

LinNames <- paste("C",1:nrow(Data), sep="")
Biplot(Data, alpha = 0.6, Title = "Biplot of data valuing individuals",
       xlabel = "X Axis", ylabel = "Y Axis", Color = TRUE, Obs = TRUE, 
       LinLab = LinNames)
       
Biplot(Data, alpha = 0.4, Title = "Graph valuing the variables",
       xlabel = "", ylabel = "", Color = FALSE, Obs = FALSE)
# }

Run the code above in your browser using DataLab