Learn R Programming

MVar (version 2.0.4)

DataFreq: Frequency data set.

Description

Simulated data set with the weekly frequency of the number of coffee cups consumed weekly in some world capitals.

Usage

data(DataFreq)

Arguments

Format

Set of data with 6 rows and 9 columns. There are 6 observations described by 9 variables: Group by sex and age, Sao Paulo - Cafe Bourbon, London - Cafe Bourbon, Athens - Cafe Bourbon, London - Cafe Acaia, Athens - Cafe Catuai, Sao Paulo - Cafe Catuai, Athens - Cafe Catuai.

Examples

Run this code
# NOT RUN {
data(DataFreq)
DataFreq
# }

Run the code above in your browser using DataLab