Learn R Programming

MVar (version 2.0.4)

DataMix: Mixed data set.

Description

Simulated set of mixed data on consumption of coffee.

Usage

data(DataMix)

Arguments

Format

Data set with 10 rows and 7 columns. Being 10 observations described by 7 variables: Cooperatives/Tasters, Average grades given to analyzed coffees, Years of work as a taster, Taster with technical training, Taster exclusively dedicated, Average frequency of the coffees Classified as special, Average frequency of the coffees as commercial.

Examples

Run this code
# NOT RUN {
data(DataMix)
DataMix
# }

Run the code above in your browser using DataLab