Learn R Programming

MVar (version 2.0.4)

DataQuan: Quantitative data set

Description

Set simulated of quantitative data on grades given to some sensory characteristics of coffees.

Usage

data(DataQuan)

Arguments

Format

Data set with 6 rows and 11 columns. Being 6 observations described by 11 variables: Coffee, Chocolate, Caramelised, Ripe, Sweet, Delicate, Nutty, Caramelised, Chocolate, Spicy, Caramelised.

Examples

Run this code
# NOT RUN {
data(DataQuan) 
DataQuan
# }

Run the code above in your browser using DataLab