Learn R Programming

MVar (version 2.0.4)

FA: Factor Analysis (FA).

Description

Performs factorial analysis (FA) in a data set.

Usage

FA(Data, Method = "PC", Type = 2, NFactor = 1, Rotation = "None",
   ScoresObs = "Bartlett", Converg = 1e-5, Iteracao = 1000, 
   TestFit = TRUE)

Arguments

Data

Data to be analyzed.

Method

Method of analysis: "PC" - Principal Components (default), "PF" - Principal Factor, "ML" - Maximum Likelihood.

Type

1 for analysis using the covariance matrix, 2 for analysis using the correlation matrix (default).

Rotation

Type of rotation: "None" (default) and "Varimax".

NFactor

Number of factors (default = 1).

ScoresObs

Type of scores for the observations: "Bartlett" (default) or "Regression".

Converg

Limit value for convergence to sum of the squares of the residuals for Maximum likelihood method (default = 1e-5).

Iteracao

Maximum number of iterations for Maximum Likelihood method (default = 1000).

TestFit

Tests the model fit to the method of Maximum Likelihood (default = TRUE).

Value

MatrixMC

Matrix of correlation / covariance.

MatrixAutoVlr

Matrix of eigenvalues.

MatrixAutoVec

Matrix of eigenvectors.

MatrixVar

Matrix of variances and proportions.

MatrixCarga

Matrix of factor loadings.

MatrixVarEsp

Matrix of specific variances.

MatrixComuna

Matrix of commonalities.

MatrixResiduo

Matrix of residues.

VlrSQRS

Upper limit value for sum of squares of the residues.

VlrSQR

Sum of squares of the residues.

MatrixResult

Matrix with all associated results.

MatrixScores

Matrix with scores of the observations.

CoefScores

Matrix with the scores of the coefficients of the factors.

References

MINGOTI, S. A. Analise de dados atraves de metodos de estatistica multivariada: uma abordagem aplicada. Belo Horizonte: UFMG, 2005. 297 p.

Kaiser, H. F.The varimax criterion for analytic rotation in factor analysis. Psychometrika 23, 187-200, 1958.

RENCHER, A. C. Methods of Multivariate Analysis. 2th. ed. New York: J.Wiley, 2002. 708 p.

FERREIRA, D. F. Estatistica Multivariada. 2a ed. revisada e ampliada. Lavras: Editora UFLA, 2011. 676 p.

See Also

Plot.FA

Examples

Run this code
# NOT RUN {
data(DataQuan) # data set

Data <- DataQuan[,2:ncol(DataQuan)]

rownames(Data) <- DataQuan[,1]

Resp <- FA(Data, Method = "PC", Type = 2, NFactor = 3, Rotation = "None",
           ScoresObs = "Bartlett", Converg = 1e-5, Iteracao = 1000, 
           TestFit = TRUE) 

print("Matrix with all associated results:"); round(Resp$MatrixResult,3)

print("Sum of squares of the residues:"); round(Resp$VlrSQR,3)

print("Matrix of the factor loadings.:"); round(Resp$MatrixCarga,3)

print("Matrix with scores of the observations:"); round(Resp$MatrixScores,3)

print("Matrix with the scores of the coefficients of the factors:"); round(Resp$CoefScores,3)

# }

Run the code above in your browser using DataLab