Learn R Programming

MVar (version 2.0.4)

GrandTour: Animation technique Grand Tour.

Description

Performs the exploration of the data through the technique of animation Grand Tour.

Usage

GrandTour(Data, Method = "Interpolation", Title = NA, 
          xlabel = NA, ylabel = NA, Color = TRUE, Label = FALSE, 
          LinLab = NA, AxisVar = TRUE, Axis = FALSE,
          NumRot = 200, ChoiceRot = NA, SavePicture = FALSE)

Arguments

Data

Numerical data set.

Method

Method used for rotations: "Interpolation" - Interpolation method (default), "Torus" - Torus method, "Pseudo" - Pseudo Grand Tour method.

Title

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

Color

Colored graphics (default = TRUE).

Label

Puts the labels of the observations (default = FALSE).

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

AxisVar

Puts axes of rotation of the variables (default = TRUE).

Axis

Plots the X and Y axes (default = TRUE).

NumRot

Number of rotations (default = 200). If Method = "Interpolation", NumRot represents the angle of rotation.

ChoiceRot

Choose specific rotation and display on the screen, or save the image if SavePicture = TRUE.

SavePicture

Saves graphics images to files (default = FALSE).

Value

Graphs with rotations.

Proj.Data

Projected data.

Vector.Opt

Vector projection.

Method

Method used on Grand Tour.

References

ASIMOV, D. The Grand Tour: A Tool for Viewing Multidimensional Data. SIAM Journal of Scientific and Statistical Computing, 6(1), 128-143, 1985.

ASIMOV, D.; BUJA, A. The grand tour via geodesic interpolation of 2-frames. in Visual Data Exploration and Analysis. Symposium on Electronic Imaging Science and Technology, IS&T/SPIE. 1994.

BUJA, A. ; ASIMOV, D. Grand tour methods: An outline. Computer Science and Statistics, 17:63-67. 1986.

BUJA, A.; COOK, D.; ASIMOV, D.; HURLEY, C. Computational Methods for High-Dimensional Rotations in Data Visualization, in C. R. Rao, E. J. Wegman & J. L. Solka, eds, "Handbook of Statistics: Data Mining and Visualization", Elsevier/North Holland, http://www.elsevier.com, pp. 391-413. 2005.

HURLEY, C.; BUJA, A. Analyzing high-dimensional data with motion graphics, SIAM Journal of Scientific and Statistical Computing, 11 (6), 1193-1211. 1990.

MARTINEZ, W. L., MARTINEZ, A. R., SOLKA, J.; Exploratory Data Analysis with MATLAB, 2th. ed. New York: Chapman & Hall/CRC, 2010. 499 p.

YOUNG, F. W.; RHEINGANS P. Visualizing structure in high-dimensional multivariate data, IBM Journal of Research and Development, 35:97-107, 1991.

YOUNG, F. W.; FALDOWSKI R. A.; McFARLANE M. M. Multivariate statistical visualization, in Handbook of Statistics, Vol 9, C. R. Rao (ed.), The Netherlands: Elsevier Science Publishers, 959-998, 1993.

Examples

Run this code
# NOT RUN {
data(iris) # database

Data <- as.data.frame(NormData(iris[,1:4],2))

Res <- GrandTour(Data, Method = "Interpolation", Title = NA, Color = TRUE,
                 Label = FALSE, LinLab = NA, AxisVar = TRUE, Axis = TRUE,
                 NumRot = 10, ChoiceRot = NA, SavePicture = FALSE)

print("Projected data:"); Res$Proj.Data
print("Projection vectors:"); Res$Vector.Opt
print("Grand Tour projection method:"); Res$Method

# }

Run the code above in your browser using DataLab