Learn R Programming

MVar (version 2.0.4)

MDS: Multidimensional Scaling (MDS).

Description

Performs Multidimensional Scaling (MDS) on a data set.

Usage

MDS(Data, Distance = "euclidean", Axis = TRUE, Title = NA,
    xlabel = NA, ylabel = NA, Color = TRUE, LinLab = NA)

Arguments

Data

Data to be analyzed.

Distance

Metric of the distance: "euclidean" (default), "maximum", "manhattan", "canberra", "binary" or "minkowski".

Color

Colored graphics (default = TRUE).

Axis

Plot the X and Y axes (default = TRUE).

Title

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

Value

Multidimensional Scaling.

MatrixD

Matrix of the distances.

References

MINGOTI, S. A. Analise de dados atraves de metodos de estatistica multivariada: uma abordagem aplicada. Belo Horizonte: UFMG, 2005. 297 p.

RENCHER, A. C. Methods of Multivariate Analysis. 2th. ed. New York: J.Wiley, 2002. 708 p.

Examples

Run this code
# NOT RUN {
data(DataQuan) # set of quantitative data

Data <- DataQuan[,2:8]

rownames(Data) <- DataQuan[1:nrow(DataQuan),1]

MD <- MDS(Data, Distance = "euclidean", Axis = TRUE, Title = NA,
          xlabel = NA, ylabel = NA, Color = TRUE, LinLab = NA)
          
print("Matrix of the distances:"); MD$MatrixD
# }

Run the code above in your browser using DataLab