Learn R Programming

MVar (version 2.0.4)

Plot.CA: Graphs of the simple (CA) and multiple correspondence analysis (MCA).

Description

Graphs of the simple (CA) and multiple correspondence analysis (MCA).

Usage

Plot.CA(CA, Titles = NA, xlabel = NA, ylabel = NA,
        Color = TRUE, LinLab = NA, Casc = TRUE)

Arguments

CA

Data of the CA function.

Titles

Titles of the graphics, if not set, assumes the default text..

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

Color

Colored graphics (default = TRUE).

LinLab

Vector with the labels for the observations, for frequency data, if not set, assumes the default text.

Casc

Cascade effect in the presentation of the graphics (default = TRUE).

Value

Returns several graphs.

See Also

CA

Examples

Run this code
# NOT RUN {
data(DataFreq) # frequency data set

Data <- DataFreq[,2:ncol(DataFreq)]

rownames(Data) <- DataFreq[1:nrow(DataFreq),1]

Resp <- CA(Data, "f") # performs CA

Tit = c("Scree-plot","Observations", "Variables", "Observations / Variables")

Plot.CA(Resp, Titles = Tit, xlabel = NA, ylabel = NA,
        Color = TRUE, LinLab = NA, Casc = FALSE)


data(DataQuali) # qualitative data set

Data <- DataQuali[,2:ncol(DataQuali)]

Resp <- CA(Data, "c", "b") # performs CA

Tit = c("","","Graph of the variables")

Plot.CA(Resp, Titles = Tit, xlabel = NA, ylabel = NA,
        Color = TRUE, LinLab = NA, Casc = FALSE)

# }

Run the code above in your browser using DataLab