Learn R Programming

MVar (version 2.0.4)

Plot.FA: Graphs of the Factorial Analysis (FA).

Description

Graphs of the Factorial Analysis (FA).

Usage

Plot.FA(FA, Titles = NA, xlabel = NA, ylabel = NA,
        Color = TRUE, LinLab = NA, Casc = TRUE)

Arguments

FA

Data of the FA function.

Titles

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

Color

Colored graphics (default = TRUE).

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

Casc

Cascade effect in the presentation of the graphics (default = TRUE).

Value

Returns several graphs.

See Also

FA

Examples

Run this code
# NOT RUN {
data(DataQuan) # database

Data <- DataQuan[,2:ncol(DataQuan)]

rownames(Data) <- DataQuan[,1]

Resp <- FA(Data, Method = "PC", Type = 2, NFactor = 3)

Tit = c("Scree-plot","Scores of the Observations","Factorial Loadings","Biplot")

Plot.FA(Resp, Titles = Tit, xlabel = NA, ylabel = NA,
        Color = TRUE, LinLab = rep("", nrow(Data)),
        Casc = TRUE)
# }

Run the code above in your browser using DataLab