Learn R Programming

MVar (version 2.0.4)

Plot.MFA: Graphics of the Multiple Factor Analysis (MFA).

Description

Graphics of the Multiple Factor Analysis (MFA).

Usage

Plot.MFA(MFA, Titles = NA, xlabel = NA, ylabel = NA,
         PosLeg = 2, BoxLeg = TRUE, Color = TRUE, 
         NamArr = FALSE, LinLab = NA, Casc = TRUE)

Arguments

MFA

Data of the MFA function.

Titles

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

PosLeg

1 for caption in the left upper corner, 2 for caption in the right upper corner (default), 3 for caption in the right lower corner, 4 for caption in the left lower corner.

BoxLeg

Puts frame in legend (default = TRUE).

Color

Colored graphics (default = TRUE).

NamArr

Puts the points names in the cloud around the centroid in the graph corresponding to the global analysis of the Individuals and Variables (default = FALSE).

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

Casc

Cascade effect in the presentation of the graphics (default = TRUE).

Value

Returns several graphs.

See Also

MFA

Examples

Run this code
# NOT RUN {
data(DataMix) # set of mixed data

Data <- DataMix[,2:ncol(DataMix)] 

rownames(Data) <- DataMix[1:nrow(DataMix),1]

GroupNames = c("Grade Cafes/Work", "Formation/Dedication", "Coffees")
           
MF <- MFA(Data, c(2,2,2), TypeGroups = c("n","c","f"), GroupNames) # performs MFA

Tit = c("Scree-Plot","Observations","Observations/Variables","Inertia of the Variable Groups")

Plot.MFA(MF, Titles = Tit, xlabel = NA, ylabel = NA,
         PosLeg = 2, BoxLeg = FALSE, Color = TRUE, 
         NamArr = FALSE, LinLab = NA, 
         Casc = FALSE) # plotting several graphs on the screen

Plot.MFA(MF, Titles = Tit, xlabel = NA, ylabel = NA,
         PosLeg = 2, BoxLeg = FALSE, Color = TRUE, 
         NamArr = FALSE, LinLab = rep("A?",10), 
         Casc = FALSE) # plotting several graphs on the screen
# }

Run the code above in your browser using DataLab