Learn R Programming

MVar (version 2.0.4)

Plot.PCA: Graphs of the Principal Components Analysis (PCA).

Description

Graphs of the Principal Components Analysis (PCA).

Usage

Plot.PCA(PC, Titles = NA, xlabel = NA, ylabel = NA,
         Color = TRUE, LinLab = NA, Casc = TRUE)

Arguments

PC

Data of the PCA function.

Titles

Titles of the graphics, if not set, assumes the default text.

xlabel

Names the X axis, if not set, assumes the default text.

ylabel

Names the Y axis, if not set, assumes the default text.

Color

Colored graphics (default = TRUE).

LinLab

Vector with the labels for the observations, if not set, assumes the default text.

Casc

Cascade effect in the presentation of the graphics (default = TRUE).

Value

Returns several graphs.

See Also

PCA

Examples

Run this code
# NOT RUN {
data(DataQuan) # set of quantitative data

Data <- DataQuan[,2:8]

rownames(Data) <- DataQuan[1:nrow(DataQuan),1]

PC <- PCA(Data, 2) # performs the PCA

Tit = c("Scree-plot","Graph of the Observations","Circle of Correlation")

Plot.PCA(PC, Titles = Tit, xlabel = NA, ylabel = NA,
         Color = TRUE, LinLab = NA, Casc = TRUE)
# }

Run the code above in your browser using DataLab