powered by
Check the normality of the data, based on the asymmetry coefficient test.
NormTest(Data, Sign = 0.05)
Data to be analyzed.
Test significance level (default 5%).
Observed Chi-square value, that is, the test statistic.
Chi-square value calculated.
Degree of freedom.
p-value.
MINGOTI, S. A. Analise de dados atraves de metodos de estatistica multivariada: uma abordagem aplicada. Belo Horizonte: UFMG, 2005. 297 p.
RENCHER, A. C. Methods of Multivariate Analysis. 2th. ed. New York: J.Wiley, 2002. 708 p.
FERREIRA, D. F. Estatistica Multivariada. 2a ed. revisada e ampliada. Lavras: Editora UFLA, 2011. 676 p.
# NOT RUN { Data <- cbind(rnorm(100,2,3), rnorm(100,1,2)) NormTest(Data) plot(density(Data)) Data <- cbind(rexp(200,3), rexp(200,3)) NormTest(Data, Sign = 0.01) plot(density(Data)) # }
Run the code above in your browser using DataLab