| Plot.CI | R Documentation |
Graph of Univariate and Multivariate Confidence Intervals.
Plot.CI(ci, title = NA, xlabel = NA, ylabel = NA, size = 0.9,
grid = TRUE, color = TRUE, savptc = FALSE, width = 3236,
height = 2000, res = 300, casc = FALSE)
ci |
Data from the CI function, or with the same structure. |
title |
Plot title; if not specified, default text is used. |
xlabel |
X-axis label; if not specified, default text is used. |
ylabel |
Y-axis label; if not specified, default text is used. |
size |
Point size in the plot. |
grid |
Adds a grid to the plot (default = TRUE). |
color |
Colored plot (default = TRUE). |
savptc |
Saves graphics images to files (default = FALSE). |
width |
Graphics images width when savptc = TRUE (defaul = 3236). |
height |
Graphics images height when savptc = TRUE (default = 2000). |
res |
Nominal resolution in ppi of the graphics images when savptc = TRUE (default = 300). |
casc |
Cascade effect in the presentation of the graphics (default = FALSE). |
Returns plot.
Paulo Cesar Ossani
CI
data(iris) # data set
res <- CI(data = iris[,1:4], sigma = NA, conf = 0.95, type = "T")
tit <- "Univariate Confidence Interval"
Plot.CI(ci = res$ciu$CIu, title = tit, xlabel = NA, ylabel = '',
size = 1, grid = TRUE, color = TRUE, savptc = FALSE,
width = 3236, height = 2000, res = 300, casc = FALSE)
tit <- "Multivariate Confidence Interval"
Plot.CI(ci = res$cim$CIm, title = tit, xlabel = NA, ylabel = '',
size = 1, grid = TRUE, color = TRUE, savptc = FALSE,
width = 3236, height = 2000, res = 300, casc = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.